@@ -639,7 +639,9 @@ def _main():
                 gmail_api_config.getboolean("include_spam_trash", False)
             opts.gmail_api_scopes = \
                 gmail_api_config.get("scopes",
-                                     default_gmail_api_scope).split(',')
+                                     default_gmail_api_scope)
+            opts.gmail_api_scopes = \
+                _str_to_list(opts.gmail_api_scopes)
 
     logger.setLevel(logging.WARNING)
 
